summaryrefslogtreecommitdiffstats
path: root/ksplashml/themeengine/standard/wndstatus.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksplashml/themeengine/standard/wndstatus.cpp')
-rw-r--r--ksplashml/themeengine/standard/wndstatus.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksplashml/themeengine/standard/wndstatus.cpp b/ksplashml/themeengine/standard/wndstatus.cpp
index f8bc3d964..04685d9cf 100644
--- a/ksplashml/themeengine/standard/wndstatus.cpp
+++ b/ksplashml/themeengine/standard/wndstatus.cpp
@@ -27,17 +27,17 @@
#include "wndstatus.h"
#include "wndstatus.moc"
// WndtqStatus::WndtqStatus(): Display a nifty status bar at
// the bottom of the screen, so the user always knows what's
// happening to his system.
-WndtqStatus::WndtqStatus( TQPalette /*pal*/,
+WndStatus::WndStatus( TQPalette /*pal*/,
int xineramaScreen,
bool atTop, bool pbVisible,
const TQFont& font,
const TQColor& fgc, const TQColor & bgc,
const TQString& icon
)
- :TQHBox( 0, "wndtqStatus", WStyle_Customize|WX11BypassWM )
+ :TQHBox( 0, "wndStatus", WStyle_Customize|WX11BypassWM )
{
setFrameStyle( TQFrame::NoFrame );
//setPalette( pal );
@@ -83,19 +83,19 @@ WndtqStatus::WndtqStatus( TQPalette /*pal*/,
m_progress->hide();
}
-void WndtqStatus::slotSetMessage( const TQString& msg )
+void WndStatus::slotSetMessage( const TQString& msg )
{
raise();
m_label->setText( msg );
}
-void WndtqStatus::slotUpdateProgress( int i )
+void WndStatus::slotUpdateProgress( int i )
{
raise();
m_progress->setProgress( i );
}
-void WndtqStatus::slotUpdateSteps( int i )
+void WndStatus::slotUpdateSteps( int i )
{
m_progress->setTotalSteps( i );
}
@@ -27,17 +27,17 @@
#include "wndstatus.h"
#include "wndstatus.moc"
-// WndtqStatus::WndtqStatus(): Display a nifty status bar at
+// WndStatus::WndStatus(): Display a nifty status bar at
// the bottom of the screen, so the user always knows what's
// happening to his system.